<!DOCTYPE html>
<html>
<head>
    <title>{% block head_title %}{% endblock %}</title>
    <meta charset="utf-8">
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/bootstrap.min.css" />
    <style type="text/css">
        body { background:#F0F2F4; }
        #container { padding-top:40px; }
        #footer { padding: 50px 180px 0; }
        #footer .span2 { height:10px; width:120px; margin:0; }
        .navbar .brand { color:#F29057; text-shadow: 0 1px 0 rgb(31, 16, 8); }
        .navbar-inner { color: #EFEBC4; }
        .progress { margin-bottom:0; }
        .color1 { background:#4D5E66; }
        .color2 { background:#BFB468; }
        .color3 { background:#EFEBC4; }
        .color4 { background:#F29057; }
        .color5 { background:#FE6D42; }
    </style>
</head>
<body>
<div class="navbar navbar-static-top">
        <div class="navbar-inner color1">
            <a class="brand" href="/"><img src="{{ STATIC_URL }}img/salmon.png" alt=Salmon /></a>
            <ul class="nav"></ul>
        </div>
    </div>
<div class="container" id="container">
    {% block content %}
    {% endblock %}
    <div class="row" id="footer">
        <div class="span2 color1"></div>
        <div class="span2 color2"></div>
        <div class="span2 color3"></div>
        <div class="span2 color4"></div>
        <div class="span2 color5"></div>
    </div>
</div>

</body>
</html>
